from matchescu.reference_store.comparison_space._in_memory import (
    InMemoryComparisonSpace,
)
from matchescu.reference_store.comparison_space._protocol import BinaryComparisonSpace


__all__ = ["BinaryComparisonSpace", "InMemoryComparisonSpace"]
